@@ -1106,6 +1106,7 @@ sparql_update_fast_send (TrackerClient      *client,
 	buffered_output_stream = g_buffered_output_stream_new_sized (output_stream,
 	                                                             TRACKER_STEROIDS_BUFFER_SIZE);
 	data_output_stream = g_data_output_stream_new (buffered_output_stream);
+	g_data_output_stream_set_byte_order (data_output_stream, G_DATA_STREAM_BYTE_ORDER_HOST_ENDIAN);
 
 	g_data_output_stream_put_int32 (data_output_stream,
 	                                strlen (query),
@@ -1283,7 +1284,7 @@ tracker_uri_vprintf_escaped (const gchar *format,
 		}
 
 		*op1 = '\0';
-		escaped = g_uri_escape_string (output_start, NULL, FALSE);
+		escaped = g_uri_escape_string (output_start, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH_ELEMENT, FALSE);
 		g_string_append (result, escaped);
 		g_free (escaped);
 
