@@ -29,12 +29,13 @@
 
 G_BEGIN_DECLS
 
-gboolean        tracker_dbus_init                    (void);
-void            tracker_dbus_shutdown                (void);
-gboolean        tracker_dbus_register_objects        (void);
-GObject        *tracker_dbus_get_object              (GType type);
-TrackerStatus  *tracker_dbus_register_notifier       (void);
-void            tracker_dbus_set_available           (gboolean available);
+gboolean        tracker_dbus_init                          (void);
+void            tracker_dbus_shutdown                      (void);
+gboolean        tracker_dbus_register_objects              (void);
+GObject        *tracker_dbus_get_object                    (GType type);
+TrackerStatus  *tracker_dbus_register_notifier             (void);
+gboolean        tracker_dbus_register_names                (void);
+gboolean        tracker_dbus_register_prepare_class_signal (void);
 
 G_END_DECLS
 
